@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: export.h 894 2005-03-13 19:19:56Z roms $ */
+/* $Id: export.h 1022 2005-05-04 16:00:01Z roms $ */
 
 /*  libticables - Ti Link Cable library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -81,7 +81,7 @@ extern "C" {
 #  endif
 # endif
 
-#elif defined(__LINUX__) || defined(__BSD__)	// GNU
+#elif defined(__LINUX__) || defined(__BSD__) || defined(__MACOSX__)	// GNU
 # define TIEXPORT extern
 
 #else
