@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: intrface.c 784 2004-09-18 17:31:54Z roms $ */
+/* $Id: intrface.c 1414 2005-07-21 17:03:21Z roms $ */
 
 /*  libtifiles - Ti File Format library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -23,8 +23,16 @@
   This unit contains the interface of the libtifiles library.
 */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+#if HAVE_LOCALE_H
+#include <locale.h>
+#endif
+
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 #ifdef __WIN32__
 #include <windows.h>
 #endif
